package cn.fw.morax.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * 考评使用目标
 *
 * @author kurisu
 */
public enum EvalUseTargetEnum implements IEnum<Integer> {
    /**
     * 考评使用目标; 1:无目标 2:第一目标 3:额外目标值
     */
    NO(1, "无目标"),
    FIRST_TARGET(2, "第一目标"),
    EXTRA_TARGET(3, "额外目标值"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    EvalUseTargetEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static EvalUseTargetEnum ofValue(final Integer value) {
        for (final EvalUseTargetEnum _enum : EvalUseTargetEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final EvalUseTargetEnum _enum : EvalUseTargetEnum.values()) {
            if (_enum.value.equals(value)) {
                return _enum.getName();
            }
        }
        return "";
    }
}
